cgexplore.terms.TargetMartiniTorsion
====================================

.. currentmodule:: cgexplore.terms

.. autoclass:: TargetMartiniTorsion
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetMartiniTorsion.human_readable
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TargetMartiniTorsion.search_string
      ~TargetMartiniTorsion.search_estring
      ~TargetMartiniTorsion.measured_atom_ids
      ~TargetMartiniTorsion.phi0
      ~TargetMartiniTorsion.torsion_k
      ~TargetMartiniTorsion.torsion_n
      ~TargetMartiniTorsion.funct
   
   